@@ -5,7 +5,7 @@ use Carp;
 use File::Basename;
 use Scalar::Util;
 
-our $VERSION = '0.0404';
+our $VERSION = '0.0405';
 my $PATH = &{ sub { return dirname( (caller)[1] ) } };
 my $OPEN_OPTIONS;
 our $CURRENT_FEATURE;
@@ -44,7 +44,7 @@ sub new : method {
     }
     
     no strict 'refs';
-    if (not defined @{$class."::features"}) {
+    if (not @{$class."::features"}) {
         croak "\@${class}::features not defined";
     }
     our @features;
